package com.biosgallery.floracat.activities;

import android.content.Intent;
import android.os.Bundle;
import android.support.design.widget.FloatingActionButton;
import android.support.design.widget.Snackbar;
import android.support.v4.app.NavUtils;
import android.support.v7.app.ActionBar;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.app.AppCompatDelegate;
import android.support.v7.widget.Toolbar;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;

import com.biosgallery.floracat.R;
import com.biosgallery.floracat.domine.Troballa;
import com.biosgallery.floracat.util.DBHandler;

/**
 * An activity representing a single Troballa detail screen. This
 * activity is only used narrow width devices. On tablet-size devices,
 * item details are presented side-by-side with a list of items
 * in a {@link TroballaListActivity}.
 */
public class TroballaDetailActivity extends AppCompatActivity {


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_troballa, menu);
        return true;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_troballa_detail);
        Toolbar toolbar = (Toolbar) findViewById(R.id.detail_toolbar);
        setSupportActionBar(toolbar);

        FloatingActionButton fab = (FloatingActionButton) findViewById(R.id.fab);
        fab.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Snackbar.make(view, R.string.guardaTroballa, Snackbar.LENGTH_LONG)
                        .setAction("Action", null).show();
                DBHandler db = new DBHandler(getApplicationContext());

                // Inserting Shop/Rows
                Log.d("Insert: ", "Inserting ..");

               // db.addTroballa(new Troballa("Genista sp.","Pantà de Riba roja d'Ebre", 41.24547d, 0.435d, 1, 1, 1));

                TroballaDetailFragment tdf = (TroballaDetailFragment)
                        getSupportFragmentManager().findFragmentById(R.id.troballa_detail_container);

                Troballa trb = tdf.getCurrentTroballa();

                if (trb.getId() != null ) {
                    db.updateTroballa(new Troballa(trb.getId(),trb.getNom(), trb.getComentaris(), trb.getCoordX(), trb.getCoordY(), trb.getFreq(), trb.getVegetacio(), trb.getEstat(),trb.getDataTroballa(),trb.getFotoPath(),trb.getCodiTaxon()));

                } else {
                    db.addTroballa(new Troballa(trb.getNom(), trb.getComentaris(), trb.getCoordX(), trb.getCoordY(),  trb.getFreq(), trb.getVegetacio(), trb.getEstat(),trb.getDataTroballa(),trb.getFotoPath(),trb.getCodiTaxon()));
                }

                /*
                // Reading all shops
                Log.d("Reading: ", "Reading all shops..");
                List<Troballa> trList = db.getAllTroballa();

                for (Troballa trob : trList) {
                    String log = "Id: " + trob.getId() + " ,Name: " + trob.getNom() + " ,Comentaris: " + trob.getComentaris();
                    // Writing shops to log
                    Log.d("Troballa: ",log);
                }*/

            }
        });


        // Show the Up button in the action bar.
        ActionBar actionBar = getSupportActionBar();
        if (actionBar != null) {
            actionBar.setDisplayHomeAsUpEnabled(true);
        }

        // savedInstanceState is non-null when there is fragment state
        // saved from previous configurations of this activity
        // (e.g. when rotating the screen from portrait to landscape).
        // In this case, the fragment will automatically be re-added
        // to its container so we don't need to manually add it.
        // For more information, see the Fragments API guide at:
        //
        // http://developer.android.com/guide/components/fragments.html
        //
        if (savedInstanceState == null) {
            // Create the detail fragment and add it to the activity
            // using a fragment transaction.
            Bundle arguments = new Bundle();
            arguments.putString(TroballaDetailFragment.ARG_ITEM_ID,
                    getIntent().getStringExtra(TroballaDetailFragment.ARG_ITEM_ID));
            TroballaDetailFragment fragment = new TroballaDetailFragment();
            fragment.setArguments(arguments);
            getSupportFragmentManager().beginTransaction()
                    .add(R.id.troballa_detail_container, fragment)
                    .commit();
        }
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        int id = item.getItemId();
        if (id == android.R.id.home) {
            // This ID represents the Home or Up button. In the case of this
            // activity, the Up button is shown. Use NavUtils to allow users
            // to navigate up one level in the application structure. For
            // more details, see the Navigation pattern on Android Design:
            //
            // http://developer.android.com/design/patterns/navigation.html#up-vs-back
            //
            NavUtils.navigateUpTo(this, new Intent(this, TroballaListActivity.class));
            return true;
        }
        if (id ==  R.id.esborrarTroballa) {
            TroballaDetailFragment tdf = (TroballaDetailFragment)
                    getSupportFragmentManager().findFragmentById(R.id.troballa_detail_container);

            Troballa trb = tdf.getCurrentTroballa();
            DBHandler db = new DBHandler(getApplicationContext());
            db.deleteTroballa(trb);
            NavUtils.navigateUpTo(this, new Intent(this, TroballaListActivity.class));
            return true;


        }
        return super.onOptionsItemSelected(item);
    }





}
