package com.biosgallery.floracat.activities;

import android.Manifest;
import android.app.Activity;
import android.app.DatePickerDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.provider.MediaStore;
import android.support.design.widget.CollapsingToolbarLayout;
import android.support.v4.app.Fragment;
import android.support.v7.app.AppCompatDelegate;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.DatePicker;
import android.widget.ImageView;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;

import com.biosgallery.floracat.R;
import com.biosgallery.floracat.domine.Troballa;
import com.biosgallery.floracat.util.DBHandler;
import com.biosgallery.floracat.util.DialogoSelectorFecha;
import com.google.android.gms.maps.model.LatLng;

import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.text.DateFormat;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.Locale;

import static android.app.Activity.RESULT_OK;

/**
 * A fragment representing a single Troballa detail screen.
 * This fragment is either contained in a {@link TroballaListActivity}
 * in two-pane mode (on tablets) or a {@link TroballaDetailActivity}
 * on handsets.
 */
public class TroballaDetailFragment extends Fragment  implements DatePickerDialog.OnDateSetListener {
    /**
     * The fragment argument representing the item ID that this fragment
     * represents.
     */
    public static final String ARG_ITEM_ID = "item_id";

    /**
     * The dummy content this fragment is presenting.
     */
    private Troballa mItem;
    private Long dia;


    private ImageView imageview;
    private Button btnSelectImage;
    private Bitmap bitmap;
    private File destination = null;
    private InputStream inputStreamImg;
    private String imgPath = null;
    private final int PICK_IMAGE_CAMERA = 1, PICK_IMAGE_GALLERY = 2;
    private LatLng objLatLng;
    private Integer idTrb;
    private Date dataTroballa;
    private String codeTaxon;
    private String nomTaxon;





    /**
     * Mandatory empty constructor for the fragment manager to instantiate the
     * fragment (e.g. upon screen orientation changes).
     */
    public TroballaDetailFragment() {
    }


    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);


        if (getArguments().containsKey(ARG_ITEM_ID) && getArguments().getString(ARG_ITEM_ID) != null) {

            // Load the dummy content specified by the fragment
            // arguments. In a real-world scenario, use a Loader
            // to load content from a content provider.

            DBHandler db = new DBHandler(getContext());
            mItem = db.getTroballa(getArguments().getString(ARG_ITEM_ID));

            Activity activity = this.getActivity();
            CollapsingToolbarLayout appBarLayout = (CollapsingToolbarLayout) activity.findViewById(R.id.toolbar_layout);
            if (appBarLayout != null) {
                appBarLayout.setTitle(mItem.getNom());
            }
        } else {
            Bundle datos = getActivity().getIntent().getExtras();
            if (datos != null) {
                codeTaxon = datos.getString("codeTaxon");
                nomTaxon = datos.getString("nomTaxon");
            }

        }

    }

    public void cambiarFecha() {
        DialogoSelectorFecha dialogo = new DialogoSelectorFecha();
        dialogo.setOnDateSetListener(this);
        Bundle args = new Bundle();
        args.putLong("fecha", System.currentTimeMillis());
        dialogo.setArguments(args);
        dialogo.show(getActivity().getSupportFragmentManager(), "selectorFecha");
    }

    @Override
    public void onDateSet(DatePicker view, int anyo, int mes, int dia) {
        Calendar calendario = Calendar.getInstance();
        calendario.setTimeInMillis(System.currentTimeMillis());
        calendario.set(Calendar.YEAR, anyo);
        calendario.set(Calendar.MONTH, mes);
        calendario.set(Calendar.DAY_OF_MONTH, dia);
        this.dia = calendario.getTimeInMillis();
        TextView tFecha = (TextView) getView().findViewById(R.id.txtFecha);
        DateFormat formato =  DateFormat.getDateInstance();
        tFecha.setText(android.text.format.DateFormat.format("dd-MMMM-yyyy", new Date(this.dia)));
        dataTroballa = new Date(this.dia);
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.troballa_detail, container, false);



        ImageView iconoFecha = (ImageView)rootView.findViewById(R.id.icono_fecha);
        iconoFecha.setOnClickListener(new View.OnClickListener() {
            //@Override
            public void onClick(View v) {
                cambiarFecha();
            }
        });

        ImageView iconoMapa = (ImageView)rootView.findViewById(R.id.icono_mapa);
        iconoMapa.setOnClickListener(new View.OnClickListener() {
            //@Override
            public void onClick(View v) {
                Intent intent = new Intent(getActivity(),  TriarPosicio.class);
                intent.putExtra("COORDENADA",objLatLng);
                startActivityForResult(intent,1);
            }
        });


        ImageView iconoFoto = (ImageView)rootView.findViewById(R.id.icono_foto);
        iconoFoto.setOnClickListener(new View.OnClickListener() {
            //@Override
            public void onClick(View v) {
                selectImage();
            }
        });


        Spinner spiFreq = (Spinner)rootView.findViewById(R.id.spinner1);
        String[] items = new String[]{"ccc: molt comuna", "cc: força comuna", "c: poc comuna", "r: poc rara", "rr: força rara", "rrr: molt rara"};
        ArrayAdapter<String> adapter = new ArrayAdapter<String>(getActivity(), android.R.layout.simple_spinner_dropdown_item, items);

        spiFreq.setAdapter(adapter);

        Spinner spiVeg = (Spinner)rootView.findViewById(R.id.spinner2);
        String[] itemsVeg = new String[]{"Prat", "Roques", "Brolla","Brolla amb Pins", "Màquia", "Bosc","Bosc Ribera","Platja","Zones inundades"};
        ArrayAdapter<String> adapter2 = new ArrayAdapter<String>(getActivity(), android.R.layout.simple_spinner_dropdown_item, itemsVeg);

        spiVeg.setAdapter(adapter2);

        Spinner spiVit = (Spinner)rootView.findViewById(R.id.spinner3);
        String[] itemsVit = new String[]{"Floració", "Fruit", "Flor i Fruit","Vegetatiu"};
        ArrayAdapter<String> adapter3 = new ArrayAdapter<String>(getActivity(), android.R.layout.simple_spinner_dropdown_item, itemsVit);

        spiVit.setAdapter(adapter3);

        Calendar calendario = Calendar.getInstance();
        Long avui = calendario.getTimeInMillis();
        dataTroballa = new Date(avui);
        Calendar today = Calendar.getInstance();
        TextView tFecha = (TextView) rootView.findViewById(R.id.txtFecha);
        tFecha.setText(android.text.format.DateFormat.format("dd-MMMM-yyyy", today));

        // Show the dummy content as text in a TextView.
        if (mItem != null) {
            copyJavaToScreen(mItem,rootView);
        }

        if (codeTaxon != null) {
            TextView txtNom = (TextView)rootView.findViewById(R.id.textInputNomTaxon);
            txtNom.setText(nomTaxon);
            txtNom.setTextColor(getResources().getColor(R.color.colorAccent));
            txtNom.setEnabled(false);
        }

        return rootView;
    }

    @Override
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (requestCode == 1) {
            if (resultCode == RESULT_OK) {
                objLatLng = data.getExtras().getParcelable("editTextValue");
                if (objLatLng != null) {
                    TextView coord = (TextView) this.getActivity().findViewById(R.id.labelCoordenades);
                    coord.setText(new DecimalFormat("##.#####").format(objLatLng.latitude)+" - "+new DecimalFormat("##.#####").format(objLatLng.longitude));
                }
            }
        }

        inputStreamImg = null;
        ImageView imgFoto = (ImageView) this.getActivity().findViewById(R.id.imageViewTroballa);
        TextView lblFoto = (TextView) this.getActivity().findViewById(R.id.labelFoto);



        if (requestCode == PICK_IMAGE_CAMERA) {
            try {
                Uri selectedImage = data.getData();
                bitmap = getPhoto(selectedImage);
                //bitmap = (Bitmap) data.getExtras().get("data");
                ByteArrayOutputStream bytes = new ByteArrayOutputStream();
                bitmap.compress(Bitmap.CompressFormat.JPEG, 50, bytes);

                Log.e("Activity", "Pick from Camera::>>> ");

                //String timeStamp = new SimpleDateFormat("yyyyMMdd_HHmmss", Locale.getDefault()).format(new Date());
                //destination = new File(Environment.getExternalStorageDirectory() + "/" +
                //        getString(R.string.app_name), "IMG_" + timeStamp + ".jpg");
                //FileOutputStream fo;
                /*try {
                    destination.createNewFile();
                    fo = new FileOutputStream(destination);
                    fo.write(bytes.toByteArray());
                    fo.close();
                } catch (FileNotFoundException e) {
                    e.printStackTrace();
                } catch (IOException e) {
                    e.printStackTrace();
                }*/
                imgPath = getRealPathFromURI(selectedImage);
              //  imgPath = destination.getAbsolutePath();
                imgFoto.setImageBitmap(bitmap);


            } catch (Exception e) {
                e.printStackTrace();
            }
        } else if (requestCode == PICK_IMAGE_GALLERY) {
            Uri selectedImage = data.getData();
            try {
                bitmap = getPhoto(selectedImage);
              //  bitmap = MediaStore.Images.Media.getBitmap(getActivity().getContentResolver(), selectedImage);
               ByteArrayOutputStream bytes = new ByteArrayOutputStream();
               bitmap.compress(Bitmap.CompressFormat.JPEG, 50, bytes);
               // Log.e("Activity", "Pick from Gallery::>>> ");

               // imgPath = getRealPathFromURI(selectedImage);
                imgPath = getRealPathFromURI(selectedImage);
                //destination = new File(imgPath.toString());
                imgFoto.setImageBitmap(bitmap);


            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    // Select image from camera and gallery
    private void selectImage() {
        try {
            PackageManager pm = getActivity().getPackageManager();
            int hasPerm = pm.checkPermission(Manifest.permission.CAMERA, getActivity().getPackageName());
            if (hasPerm == PackageManager.PERMISSION_GRANTED) {
                final CharSequence[] options = {"Fer una fotografia", "Triar de la Galeria","Cancel·la"};
                android.support.v7.app.AlertDialog.Builder builder = new android.support.v7.app.AlertDialog.Builder(getActivity());
                builder.setTitle("Triar una opció");
                builder.setItems(options, new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialog, int item) {
                        if (options[item].equals("Fer una fotografia")) {
                            dialog.dismiss();
                            Intent intent = new Intent(MediaStore.ACTION_IMAGE_CAPTURE);
                            startActivityForResult(intent, PICK_IMAGE_CAMERA);
                        } else if (options[item].equals("Triar de la Galeria")) {
                            dialog.dismiss();
                            Intent pickPhoto = new Intent(Intent.ACTION_PICK, MediaStore.Images.Media.EXTERNAL_CONTENT_URI);
                            startActivityForResult(pickPhoto, PICK_IMAGE_GALLERY);
                        } else if (options[item].equals("Cancel·la")) {
                            dialog.dismiss();
                        }
                    }
                });
                builder.show();
            } else
                Toast.makeText(getContext(), "No tens permissos per la Càmara", Toast.LENGTH_SHORT).show();
        } catch (Exception e) {
            Toast.makeText(getContext(), "No tens permissos per la Càmara", Toast.LENGTH_SHORT).show();
            e.printStackTrace();
        }
    }


    public String getRealPathFromURI(Uri contentUri) {
        String res = null;
        String[] proj = { MediaStore.Images.Media.DATA };
        Cursor cursor = getContext().getContentResolver().query(contentUri, proj, null, null, null);
        if(cursor.moveToFirst()){;
            int column_index = cursor.getColumnIndexOrThrow(MediaStore.Images.Media.DATA);
            res = cursor.getString(column_index);
        }
        cursor.close();
        return res;
    }

    public Troballa getCurrentTroballa() {
        Troballa trb = new Troballa();

        Activity activity = this.getActivity();
        TextView txtNom = (TextView) activity.findViewById(R.id.textInputNomTaxon);
        trb.setNom(txtNom.getText().toString());
        TextView txtCom = (TextView) activity.findViewById(R.id.textInputComentaris);
        trb.setComentaris(txtCom.getText().toString());

        if (objLatLng != null) {
            trb.setCoordX(objLatLng.latitude);
            trb.setCoordY(objLatLng.longitude);
        }

        if (idTrb != null) { trb.setId(idTrb); }

        if (dataTroballa != null) { trb.setDataTroballa(dataTroballa); }
        if (imgPath != null ) { trb.setFotoPath(imgPath); }
        if (codeTaxon != null ) { trb.setCodiTaxon(codeTaxon );}

        Spinner spiFreq = (Spinner)activity.findViewById(R.id.spinner1);
        trb.setFreq(spiFreq.getSelectedItemPosition());
        Spinner spiVeg = (Spinner)activity.findViewById(R.id.spinner2);
        trb.setVegetacio(spiVeg.getSelectedItemPosition());
        Spinner spiVit = (Spinner)activity.findViewById(R.id.spinner3);
        trb.setEstat(spiVit.getSelectedItemPosition());

        return trb;

    }

    private void copyJavaToScreen(Troballa trb,View view) {

        if (trb.getCoordX() != 0 && trb.getCoordY() != 0) {
            objLatLng = new LatLng(trb.getCoordX(), trb.getCoordY());
        }
        TextView txtNom = (TextView) view.findViewById(R.id.textInputNomTaxon);
        txtNom.setText(trb.getNom());
        TextView txtCom = (TextView) view.findViewById(R.id.textInputComentaris);
        txtCom.setText(trb.getComentaris());
        TextView coord = (TextView) view.findViewById(R.id.labelCoordenades);
        if (objLatLng != null) {
            coord.setText(new DecimalFormat("##.########").format(objLatLng.latitude) + " - " + new DecimalFormat("##.########").format(objLatLng.longitude));
        }
        if (trb.getId() != null) { idTrb = trb.getId(); }
        if (trb.getDataTroballa() != null) {
            dataTroballa = trb.getDataTroballa();
            TextView tFecha = (TextView) view.findViewById(R.id.txtFecha);
            DateFormat formato =  DateFormat.getDateInstance();
            tFecha.setText(android.text.format.DateFormat.format("dd-MMMM-yyyy", dataTroballa));
        }
        Spinner spiFreq = (Spinner)view.findViewById(R.id.spinner1);
        spiFreq.setSelection(trb.getFreq());
        Spinner spiVeg = (Spinner)view.findViewById(R.id.spinner2);
        spiVeg.setSelection(trb.getVegetacio());
        Spinner spiVit = (Spinner)view.findViewById(R.id.spinner3);
        spiVit.setSelection(trb.getEstat());

        if (trb.getFotoPath() != null ) {
            ImageView imgFoto = (ImageView) view.findViewById(R.id.imageViewTroballa);
            imgPath = trb.getFotoPath();

            try  {
                Uri selectedImage = Uri.fromFile(new File(trb.getFotoPath()));
                bitmap = getPhoto(selectedImage);
                //Bitmap bitmap = MediaStore.Images.Media.getBitmap(getActivity().getContentResolver(), selectedImage);
                ByteArrayOutputStream bytes = new ByteArrayOutputStream();
                bitmap.compress(Bitmap.CompressFormat.JPEG, 50, bytes);
                imgFoto.setImageBitmap(bitmap);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        if (trb.getCodiTaxon() != null) {
            txtNom.setTextColor(getResources().getColor(R.color.colorAccent));
            txtNom.setEnabled(false);
            codeTaxon = trb.getCodiTaxon();
            nomTaxon = trb.getNom();
        }


    }


    private Bitmap getPhoto(Uri selectedImage) {
        DisplayMetrics metrics = new DisplayMetrics();
        getActivity().getWindowManager().getDefaultDisplay().getMetrics(metrics);
        int height = metrics.heightPixels;
        int width = metrics.widthPixels;
        Bitmap photoBitmap = null;
        InputStream inputStream = null;
        try {
            inputStream = getActivity().getContentResolver().openInputStream(selectedImage);
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        }
        BitmapFactory.Options bitmapOptions = new BitmapFactory.Options();
        bitmapOptions.inJustDecodeBounds = true;
        BitmapFactory.decodeStream(inputStream, null, bitmapOptions);
        int imageWidth = bitmapOptions.outWidth;
        int imageHeight = bitmapOptions.outHeight;

        @SuppressWarnings("unused")
        InputStream is = null;
        try {
            is = getActivity().getContentResolver().openInputStream(selectedImage);
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        }
        float scale = 1.0f;

        if (imageWidth < imageHeight) {
            if (imageHeight > width * 1.0f) {
                scale = width * 1.0f / (imageHeight * 1.0f);
            }

        } else {
            if (imageWidth > width * 1.0f) {
                scale = width * 1.0f / (imageWidth * 1.0f);
            }

        }

        photoBitmap = decodeSampledBitmapFromResource(getContext(),
                selectedImage, (int) (imageWidth * scale),
                (int) (imageHeight * scale));
        return photoBitmap;
    }

    public static Bitmap decodeSampledBitmapFromResource(Context context,
                                                         Uri uri, int reqWidth, int reqHeight) {

        // First decode with inJustDecodeBounds=true to check dimensions
        final BitmapFactory.Options options = new BitmapFactory.Options();
        options.inJustDecodeBounds = true;
        InputStream is = null;
        try {
            is = context.getContentResolver().openInputStream(uri);
        } catch (FileNotFoundException e1) {
            // TODO Auto-generated catch block
            e1.printStackTrace();
        }
        BitmapFactory.decodeStream(is, null, options);

        // Calculate inSampleSize
        options.inSampleSize = calculateInSampleSize(options, reqWidth,
                reqHeight);

        // Decode editBitmap with inSampleSize set
        options.inJustDecodeBounds = false;
        InputStream inputs = null;
        try {
            inputs = context.getContentResolver().openInputStream(uri);
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        }

        return BitmapFactory.decodeStream(inputs, null, options);
    }

    public static int calculateInSampleSize(BitmapFactory.Options options,
                                            int reqWidth, int reqHeight) {
        // Raw height and width of image
        final int height = options.outHeight;
        final int width = options.outWidth;
        int inSampleSize = 1;

        if (height > reqHeight || width > reqWidth) {

            // Calculate ratios of height and width to requested height and
            // width
            final int heightRatio = Math.round((float) height
                    / (float) reqHeight);
            final int widthRatio = Math.round((float) width / (float) reqWidth);

            // Choose the smallest ratio as inSampleSize value, this will
            // guarantee
            // a final image with both dimensions larger than or equal to the
            // requested height and width.
            inSampleSize = Math.min(heightRatio, widthRatio);
            // inSampleSize = heightRatio < widthRatio ? heightRatio :
            // widthRatio;
        }

        return inSampleSize;
    }


}
