package com.biosgallery.floracat.activities;

import android.content.Context;
import android.content.Intent;
import android.graphics.Color;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.design.widget.FloatingActionButton;
import android.support.design.widget.Snackbar;
import android.support.v4.app.NavUtils;
import android.support.v7.app.ActionBar;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import com.biosgallery.floracat.R;
import com.biosgallery.floracat.domine.Troballa;
import com.biosgallery.floracat.util.DBHandler;
import com.yqritc.recyclerviewflexibledivider.HorizontalDividerItemDecoration;

import java.util.List;

/**
 * An activity representing a list of Troballes. This activity
 * has different presentations for handset and tablet-size devices. On
 * handsets, the activity presents a list of items, which when touched,
 * lead to a {@link TroballaDetailActivity} representing
 * item details. On tablets, the activity presents the list of items and
 * item details side-by-side using two vertical panes.
 */
public class TroballaListActivity extends AppCompatActivity {

    /**
     * Whether or not the activity is in two-pane mode, i.e. running on a tablet
     * device.
     */
    private boolean mTwoPane;
    private Integer orderList = 0;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_troballa_list);

        Toolbar toolbar = (Toolbar) findViewById(R.id.toolbar);
        setSupportActionBar(toolbar);
        toolbar.setTitle(getTitle());

        FloatingActionButton fab = (FloatingActionButton) findViewById(R.id.fab);
        fab.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Snackbar.make(view, "Creant una nova troballa", Snackbar.LENGTH_LONG)
                        .setAction("Action", null).show();


                    Intent intent = new Intent(getApplicationContext(), TroballaDetailActivity.class);
                    intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_MULTIPLE_TASK);
                    getApplicationContext().startActivity(intent);


            }
        });


        // Show the Up button in the action bar.
        ActionBar actionBar = getSupportActionBar();
        if (actionBar != null) {
            actionBar.setDisplayHomeAsUpEnabled(true);
        }

        View recyclerView = findViewById(R.id.troballa_list);
        assert recyclerView != null;
        setupRecyclerView((RecyclerView) recyclerView);

        ((RecyclerView) recyclerView).addItemDecoration( new HorizontalDividerItemDecoration.Builder(this)
                .color(Color.rgb(187,186,181))
                .size(1)
                .build());

        if (findViewById(R.id.troballa_detail_container) != null) {
            // The detail container view will be present only in the
            // large-screen layouts (res/values-w900dp).
            // If this view is present, then the
            // activity should be in two-pane mode.
            mTwoPane = true;
        }


    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        int id = item.getItemId();
        RecyclerView recyclerView = (android.support.v7.widget.RecyclerView)this.findViewById(R.id.troballa_list);
        if (id == android.R.id.home) {
            // This ID represents the Home or Up button. In the case of this
            // activity, the Up button is shown. Use NavUtils to allow users
            // to navigate up one level in the application structure. For
            // more details, see the Navigation pattern on Android Design:
            //
            // http://developer.android.com/design/patterns/navigation.html#up-vs-back
            //
            NavUtils.navigateUpFromSameTask(this);
            return true;
        }
        if (id ==  R.id.ordenarNom) {
            orderList = 0;
            setupRecyclerView(recyclerView);
            return true;
        }
        if (id ==  R.id.ordenarData) {
            orderList = 1;
            setupRecyclerView(recyclerView);
            return true;
        }
        return super.onOptionsItemSelected(item);
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_list_troballa, menu);
        return true;
    }





    @Override
    protected void onResume() {
        super.onResume();
        RecyclerView recyclerView = (android.support.v7.widget.RecyclerView)this.findViewById(R.id.troballa_list);
        setupRecyclerView(recyclerView);

    }




    private void setupRecyclerView(@NonNull RecyclerView recyclerView) {

        DBHandler db = new DBHandler(getApplicationContext());
        List<Troballa> trList = db.getAllTroballa(orderList);
        recyclerView.setAdapter(new SimpleItemRecyclerViewAdapter(trList));


    }

    public class SimpleItemRecyclerViewAdapter
            extends RecyclerView.Adapter<SimpleItemRecyclerViewAdapter.ViewHolder> {

        private final List<Troballa> mValues;

        public SimpleItemRecyclerViewAdapter(List<Troballa> items) {
            mValues = items;
        }

        @Override
        public ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
            View view = LayoutInflater.from(parent.getContext())
                    .inflate(R.layout.troballa_list_content, parent, false);
            return new ViewHolder(view);
        }



        @Override
        public void onBindViewHolder(final ViewHolder holder, int position) {
            holder.mItem = mValues.get(position);
            holder.mIdView.setText(mValues.get(position).getNom());
            if (mValues.get(position).getDataTroballa() != null ) {
                holder.mContentView.setText(android.text.format.DateFormat.format("dd/MM/yyyy", mValues.get(position).getDataTroballa()) +" - " + mValues.get(position).getComentaris());
            } else {
                holder.mContentView.setText(mValues.get(position).getComentaris());
            }

            holder.mView.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    v.setFocusableInTouchMode(true);
                    if (mTwoPane) {
                        Bundle arguments = new Bundle();
                        arguments.putString(TroballaDetailFragment.ARG_ITEM_ID, holder.mItem.getId().toString());
                        TroballaDetailFragment fragment = new TroballaDetailFragment();
                        fragment.setArguments(arguments);
                        getSupportFragmentManager().beginTransaction()
                                .replace(R.id.troballa_detail_container, fragment)
                                .commit();
                    } else {
                        Context context = v.getContext();
                        Intent intent = new Intent(context, TroballaDetailActivity.class);
                        intent.putExtra(TroballaDetailFragment.ARG_ITEM_ID, String.valueOf(holder.mItem.getId()));

                        context.startActivity(intent);
                    }
                }
            });
        }

        @Override
        public int getItemCount() {
            return mValues.size();
        }

        public class ViewHolder extends RecyclerView.ViewHolder {
            public final View mView;
            public final TextView mIdView;
            public final TextView mContentView;
            public Troballa mItem;

            public ViewHolder(View view) {
                super(view);
                mView = view;
                mIdView = (TextView) view.findViewById(R.id.id);
                mContentView = (TextView) view.findViewById(R.id.content);
            }

            @Override
            public String toString() {
                return super.toString() + " '" + mContentView.getText() + "'";
            }
        }
    }
}
