package com.biosgallery.floracat.util;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

import com.biosgallery.floracat.domine.Troballa;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import static android.provider.Contacts.SettingsColumns.KEY;
import static android.provider.Telephony.Mms.Part.TEXT;

/**
 * Created by xavier on 06/12/17.
 */

public class DBHandler  extends SQLiteOpenHelper {

    // Database Version
    private static final int DATABASE_VERSION = 1;
    // Database Name
    private static final String DATABASE_NAME = "FloraCat";
    // Contacts table name
    private static final String TABLE_TROBALLES = "troballes";

    // Shops Table Columns names
    private static final String KEY_ID = "id";
    private static final String KEY_NAME = "nom";
    private static final String KEY_COMENTARIS = "comentaris";
    private static final String KEY_CODITAXON = "codiTaxon";
    private static final String KEY_COORD_X = "coordX";
    private static final String KEY_COORD_Y = "coordY";
    private static final String KEY_FREQ = "freq";
    private static final String KEY_VEGETACIO = "vegetacio";
    private static final String KEY_ESTAT = "estat";
    private static final String KEY_DATA = "dataTroballa";
    private static final String KEY_FOTO_PATH = "fotoPath";



    public DBHandler(Context context) {
        super(context, DATABASE_NAME, null, DATABASE_VERSION);
    }
    @Override
    public void onCreate(SQLiteDatabase db) {
        String CREATE_TROBALLES_TABLE = "CREATE TABLE " + TABLE_TROBALLES + "("
        + KEY_ID + " INTEGER PRIMARY KEY," + KEY_NAME + " TEXT,"
        + KEY_COMENTARIS + " TEXT, "
        + KEY_CODITAXON + " TEXT, "
        + KEY_COORD_X + " REAL, "
        + KEY_COORD_Y + " REAL, "
        + KEY_FREQ + " INTEGER, "
        + KEY_VEGETACIO + " INTEGER, "
        + KEY_ESTAT + " INTEGER, "
        + KEY_DATA + " INTEGER NOT NULL DEFAULT (strftime('%s','now')), "
        + KEY_FOTO_PATH + " TEXT "
        + ");";

        db.execSQL(CREATE_TROBALLES_TABLE);
    }
    @Override
    public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
        // Drop older table if existed
        db.execSQL("DROP TABLE IF EXISTS " + TABLE_TROBALLES);
    // Creating tables again
        onCreate(db);
    }

    // Adding new Troballa
    public void addTroballa(Troballa troballa) {
        SQLiteDatabase db = this.getWritableDatabase();
        ContentValues values = new ContentValues();
        values.put(KEY_NAME, troballa.getNom());
        values.put(KEY_COMENTARIS, troballa.getComentaris());
        values.put(KEY_CODITAXON, troballa.getCodiTaxon());
        values.put(KEY_COORD_X, troballa.getCoordX());
        values.put(KEY_COORD_Y, troballa.getCoordY());
        values.put(KEY_FREQ, troballa.getFreq());
        values.put(KEY_VEGETACIO, troballa.getVegetacio());
        values.put(KEY_ESTAT, troballa.getEstat());
        values.put(KEY_FOTO_PATH, troballa.getFotoPath());
        values.put(KEY_DATA, persistDate(troballa.getDataTroballa()));


        // Inserting Row
        db.insert(TABLE_TROBALLES, null, values);
        db.close(); // Closing database connection
    }


    // Deleting a Troballa
    public void deleteTroballa(Troballa trb) {
        SQLiteDatabase db = this.getWritableDatabase();
        db.delete(TABLE_TROBALLES, KEY_ID + " = ?",
                new String[]{String.valueOf(trb.getId())});
        db.close();
    }

    public static Long persistDate(Date date) {
        if (date != null) {
            return date.getTime();
        }
        return null;
    }


    public static Date loadDate(Cursor cursor, int index) {
        if (cursor.isNull(index)) {
            return null;
        }
        return new Date(cursor.getLong(index));
    }

    // Getting All Troballas
    public List<Troballa> getAllTroballa(int order) {
        List<Troballa> trobList = new ArrayList<Troballa>();
        // Select All Query
        String selectQuery = "SELECT * FROM " + TABLE_TROBALLES;
        if (order == 0) {
            selectQuery = selectQuery + " ORDER BY "+KEY_NAME+" COLLATE NOCASE";
        } else if (order == 1) {
            selectQuery = selectQuery + " ORDER BY "+KEY_DATA+" DESC";
        }

        SQLiteDatabase db = this.getWritableDatabase();
        Cursor cursor = db.rawQuery(selectQuery, null);


        // looping through all rows and adding to list
        if (cursor.moveToFirst()) {
            do {
                Troballa tr = new Troballa();
                tr.setId(Integer.parseInt(cursor.getString(0)));
                tr.setNom(cursor.getString(1));
                tr.setComentaris(cursor.getString(2));
                tr.setCodiTaxon(cursor.getString(3));
                tr.setCoordX(cursor.getDouble(4));
                tr.setCoordY(cursor.getDouble(5));
                tr.setFreq(cursor.getInt(6));
                tr.setVegetacio(cursor.getInt(7));
                tr.setEstat(cursor.getInt(8));
                tr.setDataTroballa(loadDate(cursor, 9));
                tr.setFotoPath(cursor.getString(10));
                // Adding contact to list
                trobList.add(tr);
            } while (cursor.moveToNext());
        }

        // return contact list
        return trobList;
    }

    // Getting one Troballas
    public Troballa getTroballa(String id) {
        Troballa trb = new Troballa();
        // Select Query
        String selectQuery = "SELECT * FROM " + TABLE_TROBALLES + " WHERE id = " + id;

        SQLiteDatabase db = this.getWritableDatabase();
        Cursor cursor = db.rawQuery(selectQuery, null);


        if (cursor.moveToFirst()) {
            trb.setId(Integer.parseInt(cursor.getString(0)));
            trb.setNom(cursor.getString(1));
            trb.setComentaris(cursor.getString(2));
            trb.setCodiTaxon(cursor.getString(3));
            trb.setCoordX(cursor.getDouble(4));
            trb.setCoordY(cursor.getDouble(5));
            trb.setFreq(cursor.getInt(6));
            trb.setVegetacio(cursor.getInt(7));
            trb.setEstat(cursor.getInt(8));
            trb.setDataTroballa(loadDate(cursor, 9));
            trb.setFotoPath(cursor.getString(10));
        }

        // return contact list
        return trb;
    }

    // Updating a Troballa
    public int updateTroballa(Troballa trb) {
        SQLiteDatabase db = this.getWritableDatabase();

        ContentValues values = new ContentValues();

        values.put(KEY_NAME, trb.getNom());
        values.put(KEY_COMENTARIS, trb.getComentaris());
        values.put(KEY_CODITAXON, trb.getCodiTaxon());
        values.put(KEY_COORD_X, trb.getCoordX());
        values.put(KEY_COORD_Y, trb.getCoordY());
        values.put(KEY_FREQ, trb.getFreq());
        values.put(KEY_VEGETACIO, trb.getVegetacio());
        values.put(KEY_ESTAT, trb.getEstat());
        values.put(KEY_DATA, persistDate(trb.getDataTroballa()));
        values.put(KEY_FOTO_PATH, trb.getFotoPath());

        // updating row
        return db.update(TABLE_TROBALLES, values, KEY_ID + " = ?",
        new String[]{String.valueOf(trb.getId())});
    }

}
